stringtools.format_input_lines_as_doc_string
============================================

.. autofunction:: abjad.tools.stringtools.format_input_lines_as_doc_string.format_input_lines_as_doc_string
   :noindex:
